@@ -13,6 +13,7 @@ from .str import StrValidator
 from .base import Validator
 from .type import TypeValidator
 from .enum import EnumValidator
+from .email import EmailValidator
 
 from .error import ValidationError
 
@@ -31,5 +32,6 @@ __all__ = [
     StrValidator,
     TypeValidator,
     Validator,
-    ValidationError
+    ValidationError,
+    EmailValidator
 ]
\ No newline at end of file
